<?php
/**
 * SociaMonials functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package SociaMonials
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function sociamonials_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on SociaMonials, use a find and replace
		* to change 'sociamonials' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'sociamonials', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Primary', 'sociamonials' ),
			'menu-2' => esc_html__( 'Footer', 'sociamonials' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'sociamonials_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action( 'after_setup_theme', 'sociamonials_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function sociamonials_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'sociamonials_content_width', 640 );
}
add_action( 'after_setup_theme', 'sociamonials_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function sociamonials_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'sociamonials' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'sociamonials' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'sociamonials_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function sociamonials_scripts() {
	wp_enqueue_style( 'sociamonials-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_style_add_data( 'sociamonials-style', 'rtl', 'replace' );

	wp_enqueue_script( 'sociamonials-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'sociamonials_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}


class Custom_Walker_Nav_Menu extends Walker_Nav_Menu {

	function start_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat("\t", $depth);
		//$output .= "\n$indent<ul class=\"sub-menu\">\n";
  
		// Change sub-menu to dropdown menu
		$output .= "\n$indent<ul class=\"dropdown-menu\">\n";
	}
  
	function start_el ( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
	  // Most of this code is copied from original Walker_Nav_Menu
	  global $wp_query, $wpdb;
	  $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
  
	  $class_names = $value = '';
  
	  $classes = empty( $item->classes ) ? array() : (array) $item->classes;
	  $classes[] = 'nav-item';
  
	  $class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );
	  $class_names = ' class="' . esc_attr( $class_names ) . '"';
  
	  $id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );
	  $id = strlen( $id ) ? ' id="' . esc_attr( $id ) . '"' : '';
  
	  $has_children = $wpdb->get_var("SELECT COUNT(meta_id)
							  FROM wp_postmeta
							  WHERE meta_key='_menu_item_menu_item_parent'
							  AND meta_value='".$item->ID."'");
  
	  $output .= $indent . '<li' . $id . $value . $class_names .'>';
  
	  $attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
	  $attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
	  $attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
	  $attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';
  
	  // Check if menu item is in main menu
	  if ( $depth == 0 && $has_children > 0  ) {
		  // These lines adds your custom class and attribute
		  $attributes .= ' class="nav-link dropdown-toggle"';
		  $attributes .= ' data-bs-toggle="dropdown"';
	  }
	 else {
		// These lines adds your custom class and attribute
		$attributes .= ' class="nav-link "';
	
	}
  
	  $item_output = $args->before;
	  $item_output .= '<a'. $attributes .'>';
	  $item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
  
	  // Add the caret if menu level is 0
	  if ( $depth == 0 && $has_children > 0  ) {
		  $item_output .= ' <b class="caret"></b>';
	  }
  
	  $item_output .= '</a>';
	  $item_output .= $args->after;
  
	  $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}
  
  }


  /**
 * theme options
 */
if( function_exists('acf_add_options_page') ) {
	$parent = acf_add_options_page( array(
	'page_title' 	=> 'Theme Options',
	'menu_title' 	=> 'Theme Options',
	'post_id' 		=> 'theme-options',
	'redirect' 		=> false,
	'icon_url' => 'dashicons-admin-generic',
	'position' => 5
	));
}
/**
 * Pricing
 */
if( function_exists('acf_add_options_page') ) {
	$parent = acf_add_options_page( array(
	'page_title' 	=> 'Pricing Plans',
	'menu_title' 	=> 'Pricing Plans',
	'post_id' 		=> 'pricing-plans',
	'redirect' 		=> false,
	'icon_url' => 'dashicons-money-alt',
	'position' => 6
	));
}



// Allow SVG
add_filter( 'wp_check_filetype_and_ext', function($data, $file, $filename, $mimes) {

	global $wp_version;
	if ( $wp_version !== '4.7.1' ) {
	   return $data;
	}
  
	$filetype = wp_check_filetype( $filename, $mimes );
  
	return [
		'ext'             => $filetype['ext'],
		'type'            => $filetype['type'],
		'proper_filename' => $data['proper_filename']
	];
  }, 10, 4 );
  function cc_mime_types( $mimes ){
	$mimes['svg'] = 'image/svg+xml';
	return $mimes;
  }
  add_filter( 'upload_mimes', 'cc_mime_types' );
  function fix_svg() {
	echo '<style type="text/css">
		  .attachment-266x266, .thumbnail img {
			   width: 100% !important;
			   height: auto !important;
		  }
		  </style>';
  }
  add_action( 'admin_head', 'fix_svg' );


//Register Custom Post Type 
add_action( 'init', 'w3_relations_custom_post' );
function w3_relations_custom_post() {
       register_post_type( 'team_member',
        array(
            'labels' => array(
                'name' => __( 'Team Members' ),
                'singular_name' => __( 'Team Member' ),
				'add_new_item'          => __( 'Add New Team Member'),
            ),
            'supports' => array('title'),
            'public' => false,
            'show_ui' => true,
            'menu_icon'  => 'dashicons-groups',
        )
    );
	register_post_type( 'service',
	array(
		'labels' => array(
			'name' => __( 'Services' ),
			'singular_name' => __( 'Service' ),
			'add_new_item'          => __( 'Add New Service'),
			'edit_item' => __( 'Edit Service'  ),

		),
		'supports' => array('title','editor'),
		'public' => true,
		'show_ui' => true,
		'menu_icon'  => 'dashicons-format-aside',
	)
);

}